# Dojo

[Compass Labs](https://compasslabs.ai/) 🧭 developed `dojo`, an agent-based DeFi simulation software operating at the EVM smart contract level.
___

## What can you do with dojo?

 - Simulate the behavior of smart contracts in a decentralized finance (DeFi) ecosystem.
 - Test your trading strategies on real code. Get detailed performance metrics.
 - Seamlessy interact with multiple different protocols
 - Visualize your results in a dashboard.

## What's coming next
 - Switch from backtesting to live-execution. Check on/interact with your runner in real-time using a telegram bot.
 - More protocols
 - More dashboard - more fancy

## What makes dojo unique?
 - Dojo executes the exact same code as the Ethereum Virtual Machine (EVM) and is therefore able to simulate the behavior of smart contracts with accuracy.
 - With dojo, we abstract away solidity and allow you to interact with smart contracts using simple Python interfaces.
 - We provide all historic data, you won't have to care about it at all.
 - Dojo has a built-in dashboard to visualize your simulations.


## How to get started
We recommend working through our short tutorials to get started. You can find them [here](http://dojo.compasslabs.ai).  
If you have any feature request or bug report, please open an issue on [GitHub](https://github.com/CompassLabs/dojo_examples).  
We are also happy to answer any questions you may have via [mail](mailo:contact@compasslabs.ai).

___

**Some impressions**

![](https://drive.google.com/uc?export=download&id=181PEWgF9o_XLiAqC0igdrT4SoZ2AM50J)